@@ -1,6 +1,19 @@
+"""
+Module defines Platform class enumerates the popular Operating Systems.
+
+"""
 import enum
+import logging
 import platform
 
+logger = logging.getLogger(__name__)
+handler = logging.StreamHandler()
+formatter = logging.Formatter("%(levelname)s: %(message)s")
+handler.setFormatter(formatter)
+logger.addHandler(handler)
+logger.setLevel(logging.INFO)
+
+
 class Platform(enum.Enum):
     """An enum used to indicate the system's platform
 
@@ -15,11 +28,13 @@ class Platform(enum.Enum):
 
     See :py:func:`get_platform` to infer the platform from the system.
     """
+
     OTHER = 0
     LINUX = 1
     MAC = 2
     WINDOWS = 3
 
+
 def get_platform():
     """Returns the current platform
 
